@@ -139,6 +139,12 @@ class PostgresQuerySet(models.QuerySet):
             the models of the rows inserted with defaults for any fields not specified
         """
 
+        def is_empty(r):
+            return all([False for _ in r])
+
+        if not rows or is_empty(rows):
+            return []
+
         if not self.conflict_target and not self.conflict_action:
             # no special action required, use the standard Django bulk_create(..)
             return super().bulk_create(
@@ -196,11 +202,11 @@ class PostgresQuerySet(models.QuerySet):
             compiler = self._build_insert_compiler([fields], using=using)
             rows = compiler.execute_sql(return_id=True)
 
-            pk_field_name = self.model._meta.pk.name
+            _, pk_db_column = self.model._meta.pk.get_attname_column()
             if not rows or len(rows) == 0:
                 return None
 
-            return rows[0][pk_field_name]
+            return rows[0][pk_db_column]
 
         # no special action required, use the standard Django create(..)
         return super().create(**fields).pk
@@ -375,12 +381,6 @@ class PostgresQuerySet(models.QuerySet):
             the models of the rows upserted
         """
 
-        def is_empty(r):
-            return all([False for _ in r])
-
-        if not rows or is_empty(rows):
-            return []
-
         self.on_conflict(
             conflict_target,
             ConflictAction.UPDATE,
